@@ -129,11 +129,14 @@ class DucklingAnnotator(AnnotatorBase):
                     props.pop('values', None)
                     props['dim'] = dname
                     if dname == "time":
-                        try:
-                            dt = pendulum.parse(props['value'])
-                            props['value'] = dt.to_iso8601_string()
-                        except ParserError:
-                            pass
+                        if type == 'value':
+                            if 'value' in props:
+                                props['value'] = normalize_time_value(props['value'])
+                        elif type == 'interval':
+                            if 'from' in props and 'value' in props['from']:
+                                props['from']['value'] = normalize_time_value(props['from']['value'])
+                            if 'to' in props and 'value' in props['to']:
+                                props['to']['value'] = normalize_time_value(props['to']['value'])
                     if duckling2labels is None:
                         document.annotations.append(Annotation(start=start, end=end,
                                                                label=DEFAULT_DIM_LABEL,
@@ -152,6 +155,15 @@ class DucklingAnnotator(AnnotatorBase):
         return DucklingParameters
 
 
+def normalize_time_value(val):
+    try:
+        dt = pendulum.parse(val)
+        val = dt.to_iso8601_string()
+    except ParserError:
+        pass
+    return val
+
+
 def document_language(doc: Document, default: str = None):
     if doc.metadata is not None and 'language' in doc.metadata:
         return doc.metadata['language']
